@@ -106,10 +106,10 @@ def extract_features_wotarget_4(inifile):
                     csv_df_combined.Tail_base_y_shifted - csv_df_combined.Tail_base_y) ** 2)) / currPixPerMM
         csv_df['Movement_mouse_left_ear'] = (np.sqrt(
             (csv_df_combined.Ear_left_x_shifted - csv_df_combined.Ear_left_x) ** 2 + (
-                    csv_df_combined.Ear_left_x - csv_df_combined.Ear_left_y) ** 2)) / currPixPerMM
+                    csv_df_combined.Ear_left_y_shifted - csv_df_combined.Ear_left_y) ** 2)) / currPixPerMM
         csv_df['Movement_mouse_right_ear'] = (np.sqrt(
             (csv_df_combined.Ear_right_x_shifted - csv_df_combined.Ear_right_x) ** 2 + (
-                    csv_df_combined.Ear_right_x - csv_df_combined.Ear_right_y) ** 2)) / currPixPerMM
+                    csv_df_combined.Ear_right_y_shifted - csv_df_combined.Ear_right_y) ** 2)) / currPixPerMM
 
         print('Calculating hull variables...')
         ########### HULL - EUCLIDEAN DISTANCES ###########################################
